[![Travis Status](https://img.shields.io/travis/com/CameronDevine/mr_sim)](https://travis-ci.com/CameronDevine/mr_sim)
[![Documentation Status](https://readthedocs.org/projects/mr-sim/badge/?version=latest)](https://mr-sim.readthedocs.io/en/latest/?badge=latest)
[![PyPI Version](https://img.shields.io/pypi/v/mr_sim)](https://pypi.org/project/mr_sim/)
[![License](https://img.shields.io/github/license/CameronDevine/mr_sim)](LICENSE)


# MR Sim

MR Sim is a library for simulating material removal from abrasive material removal
processes. The library is built to be modular to allow different models, tool types,
tool shapes, and pressure distributions to be simulated and included.

## Installation

MR Sim can be installed using `pip` by running `pip install mr_sim`,

## Usage

Documentation on how to use MR Sim is [provided](https://mr-sim.readthedocs.io/en/latest/?badge=latest).
Furthermore, examples are located in the [examples](examples) folder and in the
documentation.
